Learn R Programming

finreportr (version 1.0.0)

AnnualReports: Acquire listing of company annual reports.

Description

Extracts and displays listing of annual reports filed by a company in a data frame.

Usage

AnnualReports(symbol, foreign = FALSE)

Arguments

symbol
A character vector specifying the stock symbol of the company of interest.
foreign
A logical vector indicating whether the company is domestic or foreign. foreign = FALSE by default.

Examples

Run this code
AnnualReports("TSLA")
AnnualReports("HTHIY", foreign = TRUE)

Run the code above in your browser using DataLab