Learn R Programming

finreportr (version 1.0.0)

CompanyInfo: Acquire basic company information.

Description

Extracts and displays basic information relating to a given company in a data frame.

Usage

CompanyInfo(symbol)

Arguments

symbol
A character vector specifying the stock symbol of the company of interest.

Examples

Run this code
CompanyInfo("GOOG")
CompanyInfo("TSLA")

Run the code above in your browser using DataLab